@@ -44,8 +44,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/opt/python3.8/include',
  'CONFINCLUDEPY': '/opt/python3.8/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/buildserver/setup/shaderc-2020.2/build/Python-3.8.5/coverage.info',
- 'COVERAGE_REPORT': '/home/buildserver/setup/shaderc-2020.2/build/Python-3.8.5/lcov-report',
+ 'COVERAGE_INFO': '/home/buildserver/setup/Python-3.8.11/coverage.info',
+ 'COVERAGE_REPORT': '/home/buildserver/setup/Python-3.8.11/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/opt/openssl1.1.1g/include '
@@ -164,6 +164,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
+ 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
@@ -555,6 +556,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
+ 'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
@@ -682,7 +684,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/buildserver/setup/shaderc-2020.2/build/Python-3.8.5:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.8.11:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/',
  'SCRIPTDIR': '/opt/python3.8/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -724,10 +726,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/buildserver/setup/shaderc-2020.2/build/Python-3.8.5:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/ '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.8.11:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/ '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/buildserver/setup/shaderc-2020.2/build/Python-3.8.5:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/ '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.8.11:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/ '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -749,8 +751,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/buildserver/setup/shaderc-2020.2/build/Python-3.8.5',
- 'abs_srcdir': '/home/buildserver/setup/shaderc-2020.2/build/Python-3.8.5',
+ 'abs_builddir': '/home/buildserver/setup/Python-3.8.11',
+ 'abs_srcdir': '/home/buildserver/setup/Python-3.8.11',
  'datarootdir': '/opt/python3.8/share',
  'exec_prefix': '/opt/python3.8',
  'prefix': '/opt/python3.8',
